@@ -258,7 +258,6 @@ namespace Breeze
                     QMouseEvent copy(
                         mouseEvent->type(),
                         _hook,
-                        _splitter.data()->mapToGlobal(_hook),
                         mouseEvent->button(),
                         mouseEvent->buttons(), mouseEvent->modifiers());
 
@@ -270,7 +269,6 @@ namespace Breeze
                    QMouseEvent copy(
                         mouseEvent->type(),
                         _splitter.data()->mapFromGlobal( mouseEvent->globalPos() ),
-                        mouseEvent->globalPos(),
                         mouseEvent->button(),
                         mouseEvent->buttons(), mouseEvent->modifiers());
 
